@@ -163,6 +163,7 @@ class Postgres(Dialect):
     class Tokenizer(Tokenizer):
         BIT_STRINGS = [("b'", "'"), ("B'", "'")]
         HEX_STRINGS = [("x'", "'"), ("X'", "'")]
+        BYTE_STRINGS = [("e'", "'"), ("E'", "'")]
         KEYWORDS = {
             **Tokenizer.KEYWORDS,
             "ALWAYS": TokenType.ALWAYS,
@@ -176,6 +177,11 @@ class Postgres(Dialect):
             "SMALLSERIAL": TokenType.SMALLSERIAL,
             "UUID": TokenType.UUID,
         }
+        QUOTES = ["'", "$$"]
+        SINGLE_TOKENS = {
+            **Tokenizer.SINGLE_TOKENS,
+            "$": TokenType.PARAMETER,
+        }
 
     class Parser(Parser):
         STRICT_CAST = False
